@@ -19,23 +19,31 @@
 """Manage logging, displaying and recording messages with required verbosity"""
 
 import datetime
-import sys
-import traceback
-import types
-import re
 import os  # needed to grab verbosity as environment variable
-from . import Globals, rpath
+import re
+import shutil
+import sys
+import textwrap
+import traceback
+from rdiff_backup import Globals
 
 LOGFILE_ENCODING = 'utf-8'
 
+# we need to define constants
+ERROR = 1
+WARNING = 2
+NOTE = 3
+INFO = 5
+DEBUG = 8  # we reserve 9 for adding the timestamp
 
-def _to_bytes(logline, encoding=LOGFILE_ENCODING):
-    """
-    Convert string into bytes for logging into file.
-    """
-    assert logline
-    assert isinstance(logline, str)
-    return logline.encode(encoding, 'backslashreplace')
+# mapping from severity to prefix (must be less than 9 characters)
+_LOG_PREFIX = {
+    1: "ERROR:",
+    2: "WARNING:",
+    3: "NOTE:",
+    5: "*",
+    8: "DEBUG:",
+}
 
 
 class LoggerError(Exception):
@@ -53,123 +61,68 @@ class Logger:
         # termverbset is true if the term_verbosity has been explicitly set
         self.termverbset = None
 
-    def setverbosity(self, verbosity_string):
-        """Set verbosity levels.  Takes a number string"""
-        try:
-            self.verbosity = int(verbosity_string)
-        except ValueError:
-            Log.FatalError("Verbosity must be a number, received '%s' "
-                           "instead." % verbosity_string)
-        if not self.termverbset:
-            self.term_verbosity = self.verbosity
-
-    def setterm_verbosity(self, termverb_string):
-        """Set verbosity to terminal.  Takes a number string"""
-        try:
-            self.term_verbosity = int(termverb_string)
-        except ValueError:
-            Log.FatalError("Terminal verbosity must be a number, received "
-                           "'%s' instead." % termverb_string)
-        self.termverbset = 1
-
-    def open_logfile(self, rpath):
-        """Inform all connections of an open logfile.
-
-        rpath.conn will write to the file, and the others will pass
-        write commands off to it.
-
-        """
-        assert not self.log_file_open
-        rpath.conn.log.Log.open_logfile_local(rpath)
-        for conn in Globals.connections:
-            conn.log.Log.open_logfile_allconn(rpath.conn)
-
-    def open_logfile_allconn(self, log_file_conn):
-        """Run on all connections to signal log file is open"""
-        self.log_file_open = 1
-        self.log_file_conn = log_file_conn
-
-    def open_logfile_local(self, rpath):
-        """Open logfile locally - should only be run on one connection"""
-        assert rpath.conn is Globals.local_connection
-        try:
-            self.logfp = rpath.open("ab")
-        except (OSError, IOError) as e:
-            raise LoggerError(
-                "Unable to open logfile %s: %s" % (rpath.path, e))
-        self.log_file_local = 1
-        self.logrp = rpath
-
-    def close_logfile(self):
-        """Close logfile and inform all connections"""
-        if self.log_file_open:
-            for conn in Globals.connections:
-                conn.log.Log.close_logfile_allconn()
-            self.log_file_conn.log.Log.close_logfile_local()
-
-    def close_logfile_allconn(self):
-        """Run on every connection"""
-        self.log_file_open = None
-
-    def close_logfile_local(self):
-        """Run by logging connection - close logfile"""
-        assert self.log_file_conn is Globals.local_connection
-        assert not self.logfp.close()
-        self.log_file_local = None
-
-    def format(self, message, verbosity):
-        """Format the message, possibly adding date information"""
-        if verbosity < 9:
-            return "%s\n" % message
-        else:
-            timestamp = datetime.datetime.now(
-                datetime.timezone.utc).astimezone().strftime(
-                    "%F %H:%M:%S.%f %z")
-            if Globals.server:
-                role = "SERVER"
-            else:
-                role = "CLIENT"
-            return "%s  <%s-%d>  %s\n" % (timestamp, role, os.getpid(), message)
-
     def __call__(self, message, verbosity):
-        """Log message that has verbosity importance
-
-        message can be a string, which is logged as-is, or a function,
-        which is then called and should return the string to be
-        logged.  We do it this way in case producing the string would
-        take a significant amount of CPU.
+        """
+        Log message that has verbosity importance
 
+        message can be a string or bytes
         """
         if verbosity > self.verbosity and verbosity > self.term_verbosity:
             return
 
         if not isinstance(message, (bytes, str)):
-            assert isinstance(message, types.FunctionType)
-            message = message()
+            raise TypeError(
+                "You can only log bytes or str, and not {lt}".format(
+                    lt=type(message)))
 
+        if Globals.get_api_version() < 201:  # compat200
+            message = "{pre} {msg}".format(pre=_LOG_PREFIX[verbosity],
+                                           msg=message)
         if verbosity <= self.verbosity:
-            self.log_to_file(message)
+            self.log_to_file(message, verbosity)
         if verbosity <= self.term_verbosity:
             self.log_to_term(message, verbosity)
 
-    def log_to_file(self, message):
+    # @API(Log.log_to_file, 200)
+    def log_to_file(self, message, verbosity=None):
         """Write the message to the log file, if possible"""
         if self.log_file_open:
             if self.log_file_local:
-                tmpstr = self.format(message, self.verbosity)
-                self.logfp.write(_to_bytes(tmpstr))
+                if Globals.get_api_version() < 201:
+                    tmpstr = self._format(message, self.verbosity)
+                    self.logfp.write(_to_bytes(tmpstr))
+                else:
+                    tmpstr = self._format(message, self.verbosity, verbosity)
+                    self.logfp.write(_to_bytes(tmpstr))
                 self.logfp.flush()
             else:
-                self.log_file_conn.log.Log.log_to_file(message)
+                if Globals.get_api_version() < 201:  # compat200
+                    self.log_file_conn.log.Log.log_to_file(message)
+                else:
+                    self.log_file_conn.log.Log.log_to_file(message, verbosity)
 
     def log_to_term(self, message, verbosity):
         """Write message to stdout/stderr"""
         if verbosity <= 2 or Globals.server:
-            termfp = sys.stderr.buffer
+            termfp = sys.stderr
         else:
-            termfp = sys.stdout.buffer
-        tmpstr = self.format(message, self.term_verbosity)
-        termfp.write(_to_bytes(tmpstr, encoding=sys.stdout.encoding))
+            termfp = sys.stdout
+        if Globals.get_api_version() < 201:  # compat200
+            tmpstr = self._format(message, self.term_verbosity)
+            termfp.write(tmpstr)
+        else:
+            tmpstr = self._format(message, self.term_verbosity, verbosity)
+            # if the verbosity is below 9 and the string isn't deemed
+            # pre-formatted by newlines (we ignore the last character)
+            if self.verbosity <= DEBUG and "\n" not in tmpstr[:-1]:
+                termfp.write(
+                    textwrap.fill(
+                        tmpstr, subsequent_indent=" " * 9,
+                        break_long_words=False,
+                        break_on_hyphens=False,
+                        width=shutil.get_terminal_size().columns - 1) + "\n")
+            else:
+                termfp.write(tmpstr)
 
     def conn(self, direction, result, req_num):
         """Log some data on the connection
@@ -180,7 +133,7 @@ class Logger:
         to the terminal, because otherwise the log file may be remote.
 
         """
-        if self.term_verbosity < 9:
+        if self.term_verbosity <= DEBUG:
             return
         if type(result) is bytes:
             result_repr = repr(result)
@@ -192,43 +145,24 @@ class Logger:
             conn_str = "Server"
         else:
             conn_str = "Client"
-        self.log_to_term(
-            "%s %s (%d): %s" % (conn_str, direction, req_num, result_repr), 9)
+        self.log_to_term("{cs} {di} ({rn}): {rr}".format(
+            cs=conn_str, di=direction, rn=req_num, rr=result_repr), DEBUG)
 
-    def FatalError(self, message, no_fatal_message=0, errlevel=1):
+    def FatalError(self, message, return_code=1):
         """Log a fatal error and exit"""
-        assert no_fatal_message == 0 or no_fatal_message == 1
-        if no_fatal_message:
-            prefix_string = ""
-        else:
-            prefix_string = "Fatal Error: "
-        self.log_to_term(prefix_string + message, 1)
-        sys.exit(errlevel)
+        self.log_to_term("Fatal Error: {em}".format(em=message), ERROR)
+        sys.exit(return_code)
 
-    def exception_to_string(self, arglist=[]):
-        """Return string version of current exception plus what's in arglist"""
-        type, value, tb = sys.exc_info()
-        s = ("Exception '%s' raised of class '%s':\n%s" %
-             (value, type, "".join(traceback.format_tb(tb))))
-        if arglist:
-            s += "__Arguments:"
-            for arg in arglist:
-                s += "\n"
-                try:
-                    s += str(arg)
-                except UnicodeError:
-                    s += str(arg).encode('ascii', 'replace')
-        return s
-
-    def exception(self, only_terminal=0, verbosity=5):
+    def exception(self, only_terminal=0, verbosity=INFO):
         """Log an exception and traceback
 
-        If only_terminal is None, log normally.  If it is 1, then only
-        log to disk if log file is local (self.log_file_open = 1).  If
-        it is 2, don't log to disk at all.
-
+        If only_terminal is zero, log normally.
+        If it is 1, then only log to disk if log file is local
+        If it is 2, don't log to disk at all.
         """
-        assert only_terminal in (0, 1, 2)
+        assert only_terminal in (0, 1, 2), (
+            "Variable only_terminal '{ot}' must be one of [012]".format(
+                ot=only_terminal))
         if (only_terminal == 0 or (only_terminal == 1 and self.log_file_open)):
             logging_func = self.__call__
         else:
@@ -236,45 +170,155 @@ class Logger:
             if verbosity >= self.term_verbosity:
                 return
 
-        exception_string = self.exception_to_string()
+        exception_string = self._exception_to_string()
         try:
             logging_func(exception_string, verbosity)
-        except IOError:
-            print("IOError while trying to log exception!")
+        except OSError:
+            print("OS error while trying to log exception!")
             print(exception_string)
 
+    # @API(Log.setverbosity, 200)
+    def setverbosity(self, verbosity_string):
+        """Set verbosity levels.  Takes a number string"""
+        try:
+            self.verbosity = int(verbosity_string)
+        except ValueError:
+            Log.FatalError("Verbosity must be a number, received '{vs}' "
+                           "instead".format(vs=verbosity_string))
+        if not self.termverbset:
+            self.term_verbosity = self.verbosity
+
+    # @API(Log.setterm_verbosity, 200)
+    def setterm_verbosity(self, termverb_string):
+        """Set verbosity to terminal.  Takes a number string"""
+        try:
+            self.term_verbosity = int(termverb_string)
+        except ValueError:
+            Log.FatalError("Terminal verbosity must be a number, received "
+                           "'{tv}' instead".format(tv=termverb_string))
+        self.termverbset = 1
+
+    def open_logfile(self, log_rp):
+        """Inform all connections of an open logfile.
+
+        log_rp.conn will write to the file, and the others will pass
+        write commands off to it.
+
+        """
+        assert not self.log_file_open, "Can't open an already opened logfile"
+        log_rp.conn.log.Log.open_logfile_local(log_rp)
+        for conn in Globals.connections:
+            conn.log.Log.open_logfile_allconn(log_rp.conn)
+
+    # @API(Log.open_logfile_allconn, 200)
+    def open_logfile_allconn(self, log_file_conn):
+        """Run on all connections to signal log file is open"""
+        self.log_file_open = 1
+        self.log_file_conn = log_file_conn
+
+    # @API(Log.open_logfile_local, 200)
+    def open_logfile_local(self, log_rp):
+        """Open logfile locally - should only be run on one connection"""
+        assert log_rp.conn is Globals.local_connection, (
+            "Action only foreseen locally and not over {conn}".format(
+                conn=log_rp.conn))
+        try:
+            self.logfp = log_rp.open("ab")
+        except OSError as exc:
+            raise LoggerError("Unable to open logfile {lf} due to "
+                              "exception '{ex}'".format(lf=log_rp, ex=exc))
+        self.log_file_local = 1
+
+    def close_logfile(self):
+        """Close logfile and inform all connections"""
+        if self.log_file_open:
+            for conn in Globals.connections:
+                conn.log.Log.close_logfile_allconn()
+            self.log_file_conn.log.Log.close_logfile_local()
+
+    # @API(Log.close_logfile_allconn, 200)
+    def close_logfile_allconn(self):
+        """Run on every connection"""
+        self.log_file_open = None
+
+    # @API(Log.close_logfile_local, 200)
+    def close_logfile_local(self):
+        """Run by logging connection - close logfile"""
+        assert self.log_file_conn is Globals.local_connection, (
+            "Action only foreseen locally and not over {lc}".format(
+                lc=self.log_file_conn))
+        self.logfp.close()
+        self.log_file_local = None
+
+    def _exception_to_string(self):
+        """Return string version of current exception"""
+        type, value, tb = sys.exc_info()
+        s = ("Exception '%s' raised of class '%s':\n%s" %
+             (value, type, "".join(traceback.format_tb(tb))))
+        return s
+
+    def _format(self, message, verbosity, msg_verbosity=None):
+        """Format the message, possibly adding date information"""
+        if verbosity <= DEBUG:
+            if msg_verbosity:
+                # pre-formatted informative messages are returned as such
+                if msg_verbosity == INFO and "\n" in message[:-1]:
+                    return "{msg}\n".format(msg=message)
+                else:
+                    return "{pre:<9}{msg}\n".format(
+                        pre=_LOG_PREFIX[msg_verbosity], msg=message)
+            else:  # compat200
+                return "{msg}\n".format(msg=message)
+        else:
+            timestamp = datetime.datetime.now(
+                datetime.timezone.utc).astimezone().strftime(
+                    "%F %H:%M:%S.%f %z")
+            if Globals.server:
+                role = "SERVER"
+            else:
+                role = "CLIENT"
+            if msg_verbosity:
+                return "{time}  <{role}-{pid}>  {pre} {msg}\n".format(
+                    time=timestamp, role=role, pid=os.getpid(),
+                    pre=_LOG_PREFIX[msg_verbosity], msg=message)
+            else:  # compat200
+                return "{time}  <{role}-{pid}>  {msg}\n".format(
+                    time=timestamp, role=role, pid=os.getpid(), msg=message)
+
 
 Log = Logger()
 
 
 class ErrorLog:
-    """Log each recoverable error in error_log file
+    """
+    Log each recoverable error in error_log file
 
     There are three types of recoverable errors:  ListError, which
     happens trying to list a directory or stat a file, UpdateError,
     which happen when trying to update a changed file, and
     SpecialFileError, which happen when a special file cannot be
     created.  See the error policy file for more info.
-
     """
     _log_fileobj = None
 
     @classmethod
+    # @API(ErrorLog.open, 200)
     def open(cls, time_string, compress=1):
         """Open the error log, prepare for writing"""
         if not Globals.isbackup_writer:
             return Globals.backup_writer.log.ErrorLog.open(
                 time_string, compress)
-        assert not cls._log_fileobj, "log already open"
-        assert Globals.isbackup_writer
+        assert not cls._log_fileobj, "Log already open, can't be reopened"
 
         base_rp = Globals.rbdir.append("error_log.%s.data" % time_string)
         if compress:
+            from . import rpath
             cls._log_fileobj = rpath.MaybeGzip(base_rp)
         else:
             cls._log_fileobj = base_rp.open("wb", compress=0)
 
     @classmethod
+    # @API(ErrorLog.isopen, 200)
     def isopen(cls):
         """True if the error log file is currently open"""
         if Globals.isbackup_writer or not Globals.backup_writer:
@@ -283,13 +327,40 @@ class ErrorLog:
             return Globals.backup_writer.log.ErrorLog.isopen()
 
     @classmethod
-    def write(cls, error_type, rp, exc):
-        """Add line to log file indicating error exc with file rp"""
-        if not Globals.isbackup_writer:
-            return Globals.backup_writer.log.ErrorLog.write(
+    # @API(ErrorLog.write_if_open, 200)
+    def write_if_open(cls, error_type, rp, exc):
+        """Call cls._write(...) if error log open, only log otherwise"""
+        if not Globals.isbackup_writer and Globals.backup_writer:
+            return Globals.backup_writer.log.ErrorLog.write_if_open(
                 error_type, rp, exc)
-        logstr = cls.get_log_string(error_type, rp, exc)
-        Log(logstr, 2)
+        if cls.isopen():
+            cls._write(error_type, rp, exc)
+        else:
+            Log(cls._get_log_string(error_type, rp, exc), WARNING)
+
+    @classmethod
+    # @API(ErrorLog.close, 200)
+    def close(cls):
+        """Close the error log file"""
+        if cls.isopen():
+            if not Globals.isbackup_writer:
+                return Globals.backup_writer.log.ErrorLog.close()
+            cls._log_fileobj.close()
+            cls._log_fileobj = None
+
+    @classmethod
+    def _get_log_string(cls, error_type, rp, exc):
+        """Return log string to put in error log"""
+        assert (error_type == "ListError" or error_type == "UpdateError"
+                or error_type == "SpecialFileError"), (
+            "Unknown error type {et}".format(et=error_type))
+        return "{et}: '{rp}' {ex}".format(et=error_type, rp=rp, ex=exc)
+
+    @classmethod
+    def _write(cls, error_type, rp, exc):
+        """Add line to log file indicating error exc with file rp"""
+        logstr = cls._get_log_string(error_type, rp, exc)
+        Log(logstr, WARNING)
         if Globals.null_separator:
             logstr += "\0"
         else:
@@ -297,36 +368,12 @@ class ErrorLog:
             logstr += "\n"
         cls._log_fileobj.write(_to_bytes(logstr))
 
-    @classmethod
-    def get_indexpath(cls, obj):
-        """Return filename for logging.  rp is a rpath, string, or tuple"""
-        if getattr(obj, 'get_safeindexpath', None):
-            return obj.get_safeindexpath()
-        else:
-            return repr(obj)
 
-    @classmethod
-    def write_if_open(cls, error_type, rp, exc):
-        """Call cls.write(...) if error log open, only log otherwise"""
-        if not Globals.isbackup_writer and Globals.backup_writer:
-            return Globals.backup_writer.log.ErrorLog.write_if_open(
-                error_type, rp, exc)
-        if cls.isopen():
-            cls.write(error_type, rp, exc)
-        else:
-            Log(cls.get_log_string(error_type, rp, exc), 2)
-
-    @classmethod
-    def get_log_string(cls, error_type, rp, exc):
-        """Return log string to put in error log"""
-        assert (error_type == "ListError" or error_type == "UpdateError"
-                or error_type == "SpecialFileError"), "Unknown type " + error_type
-        return "%s: '%s' %s" % (error_type, cls.get_indexpath(rp), exc)
-
-    @classmethod
-    def close(cls):
-        """Close the error log file"""
-        if not Globals.isbackup_writer:
-            return Globals.backup_writer.log.ErrorLog.close()
-        assert not cls._log_fileobj.close()
-        cls._log_fileobj = None
+def _to_bytes(logline, encoding=LOGFILE_ENCODING):
+    """
+    Convert string into bytes for logging into file.
+    """
+    assert logline, "There must be a text to encode"
+    assert isinstance(logline, str), (
+        "Text to encode must be str and not {lt}".format(lt=type(logline)))
+    return logline.encode(encoding, 'backslashreplace')
