@@ -3,11 +3,11 @@ import os
 import io
 import pwd
 import grp
-from rdiff_backup.eas_acls import AccessControlLists, metadata, ACLExtractor, \
-    Record2ACL, ACL2Record, ExtendedAttributes, EAExtractor, EA2Record, Record2EA
 from rdiff_backup import Globals, rpath, user_group
-from commontest import rdiff_backup, abs_test_dir, abs_output_dir, abs_restore_dir, \
-    BackupRestoreSeries, CompareRecursive
+from rdiffbackup import meta_mgr
+from rdiffbackup.meta import acl_posix, ea
+from commontest import rdiff_backup, abs_test_dir, abs_output_dir, \
+    abs_restore_dir, BackupRestoreSeries, compare_recursive
 
 user_group.init_user_mapping()
 user_group.init_group_mapping()
@@ -17,7 +17,7 @@ restore_dir = rpath.RPath(Globals.local_connection, abs_restore_dir)
 
 class EATest(unittest.TestCase):
     """Test extended attributes"""
-    sample_ea = ExtendedAttributes(
+    sample_ea = ea.ExtendedAttributes(
         (), {
             b'user.empty':
             b'',
@@ -32,14 +32,14 @@ class EATest(unittest.TestCase):
                 Encoding it will require several lines of
                 base64.""" + bytes((177, ) * 300)
         })
-    empty_ea = ExtendedAttributes(())
-    ea1 = ExtendedAttributes(('e1', ), sample_ea.attr_dict.copy())
+    empty_ea = ea.ExtendedAttributes(())
+    ea1 = ea.ExtendedAttributes(('e1', ), sample_ea.attr_dict.copy())
     ea1.delete(b'user.not_empty')
-    ea2 = ExtendedAttributes(('e2', ), sample_ea.attr_dict.copy())
+    ea2 = ea.ExtendedAttributes(('e2', ), sample_ea.attr_dict.copy())
     ea2.set(b'user.third', b'Another random attribute')
-    ea3 = ExtendedAttributes(('e3', ))
-    ea4 = ExtendedAttributes(('e4', ),
-                             {b'user.deleted': b'File to be deleted'})
+    ea3 = ea.ExtendedAttributes(('e3', ))
+    ea4 = ea.ExtendedAttributes(('e4', ),
+                                {b'user.deleted': b'File to be deleted'})
     ea_test1_dir = os.path.join(abs_test_dir, b'ea_test1')
     ea_test1_rpath = rpath.RPath(Globals.local_connection, ea_test1_dir)
     ea_test2_dir = os.path.join(abs_test_dir, b'ea_test2')
@@ -60,41 +60,39 @@ class EATest(unittest.TestCase):
     def testBasic(self):
         """Test basic writing and reading of extended attributes"""
         self.make_temp_out_dirs()
-        new_ea = ExtendedAttributes(())
+        new_ea = ea.ExtendedAttributes(())
         new_ea.read_from_rp(tempdir)
-        # we ignore SELinux extended attributes for comparaison
+        # we ignore SELinux extended attributes for comparison
         if new_ea.attr_dict:
             new_ea.attr_dict.pop(b'security.selinux', None)
-        assert not new_ea.attr_dict, "The attributes of %s should have been empty: %s" % (
-            tempdir, new_ea.attr_dict)
-        assert not new_ea == self.sample_ea
-        assert new_ea != self.sample_ea
-        assert new_ea == self.empty_ea
+        self.assertFalse(
+            new_ea.attr_dict,
+            "The attributes of {dir} should have been empty: {attr}".format(
+                dir=tempdir, attr=new_ea.attr_dict))
+        self.assertNotEqual(new_ea, self.sample_ea)
+        self.assertEqual(new_ea, self.empty_ea)
 
         self.sample_ea.write_to_rp(tempdir)
         new_ea.read_from_rp(tempdir)
         if new_ea.attr_dict:
             new_ea.attr_dict.pop(b'security.selinux', None)
-        assert new_ea.attr_dict == self.sample_ea.attr_dict, \
-            (new_ea.attr_dict, self.sample_ea.attr_dict)
-        assert new_ea == self.sample_ea
+        self.assertEqual(new_ea.attr_dict, self.sample_ea.attr_dict)
+        self.assertEqual(new_ea, self.sample_ea)
 
     def testRecord(self):
         """Test writing a record and reading it back"""
-        record = EA2Record(self.sample_ea)
-        new_ea = Record2EA(record)
+        record = ea.ExtendedAttributesFile._object_to_record(self.sample_ea)
+        new_ea = ea.EAExtractor._record_to_object(record)
         if not new_ea == self.sample_ea:
             new_list = list(new_ea.attr_dict.keys())
             sample_list = list(self.sample_ea.attr_dict.keys())
             new_list.sort()
             sample_list.sort()
-            assert new_list == sample_list, (new_list, sample_list)
+            self.assertEqual(new_list, sample_list)
             for name in new_list:
-                assert self.sample_ea.get(name) == new_ea.get(name), \
-                    (self.sample_ea.get(name), new_ea.get(name))
-            assert self.sample_ea.index == new_ea.index, \
-                (self.sample_ea.index, new_ea.index)
-            assert 0, "We shouldn't have gotten this far"
+                self.assertEqual(self.sample_ea.get(name), new_ea.get(name))
+            self.assertEqual(self.sample_ea.index, new_ea.index)
+            self.assertFalse("We shouldn't have gotten this far")
 
     def testExtractor(self):
         """Test seeking inside a record list"""
@@ -112,30 +110,24 @@ user.empty
 # file: 2foo/\\012
 user.empty
 """
-        extractor = EAExtractor(io.BytesIO(os.fsencode(record_list)))
-        ea_iter = extractor.iterate_starting_with(())
+        extractor = ea.EAExtractor(io.BytesIO(os.fsencode(record_list)))
+        ea_iter = extractor._iterate_starting_with(())
         first = next(ea_iter)
-        assert first.index == (b'0foo', ), first
+        self.assertEqual(first.index, (b'0foo', ))
         second = next(ea_iter)
-        assert second.index == (b'1foo', b'bar', b'baz'), second
+        self.assertEqual(second.index, (b'1foo', b'bar', b'baz'))
         third = next(ea_iter)  # Test quoted filenames
-        assert third.index == (b'2foo', b'\n'), third.index
-        try:
+        self.assertEqual(third.index, (b'2foo', b'\n'))
+        with self.assertRaises(StopIteration,
+                               msg="Too many elements in iterator"):
             next(ea_iter)
-        except StopIteration:
-            pass
-        else:
-            assert 0, "Too many elements in iterator"
 
-        extractor = EAExtractor(io.BytesIO(os.fsencode(record_list)))
-        ea_iter = extractor.iterate_starting_with((b'1foo', b'bar'))
-        assert next(ea_iter).index == (b'1foo', b'bar', b'baz')
-        try:
+        extractor = ea.EAExtractor(io.BytesIO(os.fsencode(record_list)))
+        ea_iter = extractor._iterate_starting_with((b'1foo', b'bar'))
+        self.assertEqual(next(ea_iter).index, (b'1foo', b'bar', b'baz'))
+        with self.assertRaises(StopIteration,
+                               msg="Too many elements in iterator"):
             next(ea_iter)
-        except StopIteration:
-            pass
-        else:
-            assert 0, "Too many elements in iterator"
 
     def make_backup_dirs(self):
         """Create testfiles/ea_test[12] directories
@@ -183,44 +175,38 @@ user.empty
 
         # Now write records corresponding to above rps into file
         Globals.rbdir = tempdir
-        man = metadata.PatchDiffMan()
-        writer = man.get_ea_writer('snapshot', 10000)
+        man = meta_mgr.PatchDiffMan()
+        writer = man._writer_helper('snapshot', 10000,
+                                    ea.get_plugin_class(), force=True)
         for rp in [self.ea_test1_rpath, rp1, rp2, rp3]:
-            ea = ExtendedAttributes(rp.index)
-            ea.read_from_rp(rp)
-            writer.write_object(ea)
+            # without enforcing, rp3 might have no EA and not be saved
+            writer.write_object(rp, force_empty=True)
         writer.close()
 
         # Read back records and compare
-        ea_iter = man.get_eas_at_time(10000, None)
-        assert ea_iter, "No extended_attributes.<time> file found"
+        ea_iter = man._iter_helper(10000, None, ea.get_plugin_class())
+        self.assertTrue(ea_iter, "No extended_attributes.<time> file found")
         sample_ea_reread = next(ea_iter)
-        # we ignore SELinux extended attributes for comparaison
+        # we ignore SELinux extended attributes for comparison
         if sample_ea_reread.attr_dict:
             sample_ea_reread.attr_dict.pop(b'security.selinux', None)
-        assert sample_ea_reread == self.sample_ea, "Re-read EAs %s are different from %s" % \
-            (sample_ea_reread.attr_dict, self.sample_ea.attr_dict)
+        # Check if re-read EAs are different from sample ones
+        self.assertEqual(sample_ea_reread, self.sample_ea)
         ea1_reread = next(ea_iter)
         if ea1_reread.attr_dict:
             ea1_reread.attr_dict.pop(b'security.selinux', None)
-        assert ea1_reread == self.ea1, "Re-read EAs %s are different from %s" % \
-            (ea1_reread.attr_dict, self.ea1.attr_dict)
+        self.assertEqual(ea1_reread, self.ea1)
         ea2_reread = next(ea_iter)
         if ea2_reread.attr_dict:
             ea2_reread.attr_dict.pop(b'security.selinux', None)
-        assert ea2_reread == self.ea2, "Re-read EAs %s are different from %s" % \
-            (ea2_reread.attr_dict, self.ea2.attr_dict)
+        self.assertEqual(ea2_reread, self.ea2)
         ea3_reread = next(ea_iter)
         if ea3_reread.attr_dict:
             ea3_reread.attr_dict.pop(b'security.selinux', None)
-        assert ea3_reread == self.ea3, "Re-read EAs %s are different from %s" % \
-            (ea3_reread.attr_dict, self.ea3.attr_dict)
-        try:
+        self.assertEqual(ea3_reread, self.ea3)
+        with self.assertRaises(StopIteration,
+                               msg="Too many elements in iterator"):
             next(ea_iter)
-        except StopIteration:
-            pass
-        else:
-            assert 0, "Expected end to iterator"
 
     def testSeriesLocal(self):
         """Test backing up and restoring directories with EAs locally"""
@@ -249,23 +235,24 @@ user.empty
                      self.ea_test1_rpath.path,
                      tempdir.path,
                      current_time=10000)
-        assert CompareRecursive(self.ea_test1_rpath, tempdir, compare_eas=1)
+        self.assertTrue(
+            compare_recursive(self.ea_test1_rpath, tempdir, compare_eas=1))
 
         rdiff_backup(1,
                      1,
                      self.ea_test2_rpath.path,
                      tempdir.path,
                      current_time=20000)
-        assert CompareRecursive(self.ea_test2_rpath, tempdir, compare_eas=1)
+        self.assertTrue(
+            compare_recursive(self.ea_test2_rpath, tempdir, compare_eas=1))
 
         rdiff_backup(1,
                      1,
                      tempdir.path,
                      restore_dir.path,
                      extra_options=b'-r 10000')
-        assert CompareRecursive(self.ea_test1_rpath,
-                                restore_dir,
-                                compare_eas=1)
+        self.assertTrue(
+            compare_recursive(self.ea_test1_rpath, restore_dir, compare_eas=1))
 
 
 class ACLTest(unittest.TestCase):
@@ -274,13 +261,13 @@ class ACLTest(unittest.TestCase):
     current_user = os.getenv('RDIFF_TEST_USER', pwd.getpwuid(os.getuid()).pw_name)
     current_group = os.getenv('RDIFF_TEST_GROUP', grp.getgrgid(os.getgid()).gr_name)
 
-    sample_acl = AccessControlLists((), """user::rwx
+    sample_acl = acl_posix.AccessControlLists((), """user::rwx
 user:root:rwx
 group::r-x
 group:root:r-x
 mask::r-x
 other::---""")
-    dir_acl = AccessControlLists((), """user::rwx
+    dir_acl = acl_posix.AccessControlLists((), """user::rwx
 user:root:rwx
 group::r-x
 group:root:r-x
@@ -291,23 +278,24 @@ default:user:root:---
 default:group::r-x
 default:mask::r-x
 default:other::---""")
-    acl1 = AccessControlLists((b'a1', ), """user::r--
+    acl1 = acl_posix.AccessControlLists((b'a1', ), """user::r--
 user:{0}:---
 group::---
 group:root:---
 mask::---
 other::---""".format(current_user))
-    acl2 = AccessControlLists((b'a2', ), """user::rwx
+    acl2 = acl_posix.AccessControlLists((b'a2', ), """user::rwx
 group::r-x
 group:{0}:rwx
 mask::---
 other::---""".format(current_group))
-    acl3 = AccessControlLists((b'a3', ), """user::rwx
+    acl3 = acl_posix.AccessControlLists((b'a3', ), """user::rwx
 user:root:---
 group::r-x
 mask::---
 other::---""")
-    empty_acl = AccessControlLists((), "user::rwx\ngroup::---\nother::---")
+    empty_acl = acl_posix.AccessControlLists(
+        (), "user::rwx\ngroup::---\nother::---")
     acl_test1_dir = os.path.join(abs_test_dir, b'acl_test1')
     acl_test1_rpath = rpath.RPath(Globals.local_connection, acl_test1_dir)
     acl_test2_dir = os.path.join(abs_test_dir, b'acl_test2')
@@ -328,52 +316,51 @@ other::---""")
     def testBasic(self):
         """Test basic writing and reading of ACLs"""
         self.make_temp_out_dirs()
-        new_acl = AccessControlLists(())
+        new_acl = acl_posix.AccessControlLists(())
         tempdir.chmod(0o700)
         new_acl.read_from_rp(tempdir)
-        assert new_acl.is_basic(), str(new_acl)
-        assert not new_acl == self.sample_acl
-        assert new_acl != self.sample_acl
-        assert new_acl == self.empty_acl, \
-            (str(new_acl), str(self.empty_acl))
+        self.assertTrue(new_acl.is_basic())
+        self.assertNotEqual(new_acl, self.sample_acl)
+        self.assertEqual(new_acl, self.empty_acl)
 
         self.sample_acl.write_to_rp(tempdir)
         new_acl.read_from_rp(tempdir)
-        assert str(new_acl) == str(self.sample_acl), \
-            (str(new_acl), str(self.sample_acl))
-        assert new_acl == self.sample_acl
+        self.assertEqual(str(new_acl), str(self.sample_acl))
+        self.assertEqual(new_acl, self.sample_acl)
 
     def testBasicDir(self):
         """Test reading and writing of ACL w/ defaults to directory"""
         self.make_temp_out_dirs()
-        new_acl = AccessControlLists(())
+        new_acl = acl_posix.AccessControlLists(())
         new_acl.read_from_rp(tempdir)
-        assert new_acl.is_basic()
-        assert new_acl != self.dir_acl
+        self.assertTrue(new_acl.is_basic())
+        self.assertNotEqual(new_acl, self.dir_acl)
 
         self.dir_acl.write_to_rp(tempdir)
         new_acl.read_from_rp(tempdir)
-        assert not new_acl.is_basic()
+        self.assertFalse(new_acl.is_basic())
         if not new_acl == self.dir_acl:
-            assert new_acl.eq_verbose(self.dir_acl)
-            assert 0, "Shouldn't be here---eq != eq_verbose?"
+            self.assertTrue(new_acl._eq_verbose(self.dir_acl))
+            self.assertFalse("Shouldn't be here---eq != _eq_verbose?")
 
     def testRecord(self):
         """Test writing a record and reading it back"""
-        record = ACL2Record(self.sample_acl)
-        new_acl = Record2ACL(record)
-        if new_acl != self.sample_acl:
-            print("New_acl", new_acl.entry_list)
-            print("sample_acl", self.sample_acl.entry_list)
-            print("New_acl text", str(new_acl))
-            print("sample acl text", str(self.sample_acl))
-            assert 0
+        record = acl_posix.AccessControlListFile._object_to_record(
+            self.sample_acl)
+        new_acl = acl_posix.ACLExtractor._record_to_object(record)
+        self.assertEqual(new_acl, self.sample_acl,
+                         "New_acl {new.entry_list}\n"
+                         "sample_acl {sample.entry_list}\n"
+                         "New_acl text {new!s}\n"
+                         "Sample acl text {sample!s}".format(
+                             new=new_acl, sample=self.sample_acl))
 
-        record2 = ACL2Record(self.dir_acl)
-        new_acl2 = Record2ACL(record2)
+        record2 = acl_posix.AccessControlListFile._object_to_record(
+            self.dir_acl)
+        new_acl2 = acl_posix.ACLExtractor._record_to_object(record2)
         if not new_acl2 == self.dir_acl:
-            assert new_acl2.eq_verbose(self.dir_acl)
-            assert 0
+            self.assertTrue(new_acl2._eq_verbose(self.dir_acl))
+            self.assertFalse("Shouldn't be here---eq != _eq_verbose?")
 
     def testExtractor(self):
         """Test seeking inside a record list"""
@@ -399,30 +386,24 @@ group:root:---
 mask::---
 other::---
 """.format(self.current_user)
-        extractor = ACLExtractor(io.BytesIO(os.fsencode(record_list)))
-        acl_iter = extractor.iterate_starting_with(())
+        extractor = acl_posix.ACLExtractor(io.BytesIO(os.fsencode(record_list)))
+        acl_iter = extractor._iterate_starting_with(())
         first = next(acl_iter)
-        assert first.index == (b'0foo', ), first
+        self.assertEqual(first.index, (b'0foo', ))
         second = next(acl_iter)
-        assert second.index == (b'1foo', b'bar', b'baz'), second
+        self.assertEqual(second.index, (b'1foo', b'bar', b'baz'))
         third = next(acl_iter)  # Test quoted filenames
-        assert third.index == (b'2foo', b'\n'), third.index
-        try:
+        self.assertEqual(third.index, (b'2foo', b'\n'))
+        with self.assertRaises(StopIteration,
+                               msg="Too many elements in iterator"):
             next(acl_iter)
-        except StopIteration:
-            pass
-        else:
-            assert 0, "Too many elements in iterator"
 
-        extractor = ACLExtractor(io.BytesIO(os.fsencode(record_list)))
-        acl_iter = extractor.iterate_starting_with((b'1foo', b'bar'))
-        assert next(acl_iter).index == (b'1foo', b'bar', b'baz')
-        try:
+        extractor = acl_posix.ACLExtractor(io.BytesIO(os.fsencode(record_list)))
+        acl_iter = extractor._iterate_starting_with((b'1foo', b'bar'))
+        self.assertEqual(next(acl_iter).index, (b'1foo', b'bar', b'baz'))
+        with self.assertRaises(StopIteration,
+                               msg="Too many elements in iterator"):
             next(acl_iter)
-        except StopIteration:
-            pass
-        else:
-            assert 0, "Too many elements in iterator"
 
     def make_backup_dirs(self):
         """Create testfiles/acl_test[12] directories"""
@@ -464,31 +445,27 @@ other::---
 
         # Now write records corresponding to above rps into file
         Globals.rbdir = tempdir
-        man = metadata.PatchDiffMan()
-        writer = man.get_acl_writer('snapshot', 10000)
+        man = meta_mgr.PatchDiffMan()
+        writer = man._writer_helper('snapshot', 10000,
+                                    acl_posix.get_plugin_class(), force=True)
         for rp in [self.acl_test1_rpath, rp1, rp2, rp3]:
-            acl = AccessControlLists(rp.index)
-            acl.read_from_rp(rp)
-            writer.write_object(acl)
+            writer.write_object(rp)
         writer.close()
 
         # Read back records and compare
-        acl_iter = man.get_acls_at_time(10000, None)
-        assert acl_iter, "No acl file found"
+        acl_iter = man._iter_helper(10000, None, acl_posix.get_plugin_class())
+        self.assertTrue(acl_iter, "No acl file found")
         dir_acl_reread = next(acl_iter)
-        assert dir_acl_reread == self.dir_acl
+        self.assertEqual(dir_acl_reread, self.dir_acl)
         acl1_reread = next(acl_iter)
-        assert acl1_reread == self.acl1
+        self.assertEqual(acl1_reread, self.acl1)
         acl2_reread = next(acl_iter)
-        assert acl2_reread == self.acl2
+        self.assertEqual(acl2_reread, self.acl2)
         acl3_reread = next(acl_iter)
-        assert acl3_reread == self.acl3
-        try:
-            extra = next(acl_iter)
-        except StopIteration:
-            pass
-        else:
-            assert 0, "Got unexpected object: " + repr(extra)
+        self.assertEqual(acl3_reread, self.acl3)
+        with self.assertRaises(StopIteration,
+                               msg="Too many elements in iterator"):
+            next(acl_iter)
 
     def testSeriesLocal(self):
         """Test backing up and restoring directories with ACLs locally"""
@@ -517,23 +494,25 @@ other::---
                      self.acl_test1_rpath.path,
                      tempdir.path,
                      current_time=10000)
-        assert CompareRecursive(self.acl_test1_rpath, tempdir, compare_acls=1)
+        self.assertTrue(
+            compare_recursive(self.acl_test1_rpath, tempdir, compare_acls=1))
 
         rdiff_backup(1,
                      1,
                      self.acl_test2_rpath.path,
                      tempdir.path,
                      current_time=20000)
-        assert CompareRecursive(self.acl_test2_rpath, tempdir, compare_acls=1)
+        self.assertTrue(
+            compare_recursive(self.acl_test2_rpath, tempdir, compare_acls=1))
 
         rdiff_backup(1,
                      1,
                      tempdir.path,
                      restore_dir.path,
                      extra_options=b'-r 10000')
-        assert CompareRecursive(self.acl_test1_rpath,
-                                restore_dir,
-                                compare_acls=1)
+        self.assertTrue(
+            compare_recursive(self.acl_test1_rpath, restore_dir,
+                              compare_acls=1))
 
         restore_dir.delete()
         rdiff_backup(1,
@@ -541,9 +520,9 @@ other::---
                      tempdir.path,
                      restore_dir.path,
                      extra_options=b'-r now')
-        assert CompareRecursive(self.acl_test2_rpath,
-                                restore_dir,
-                                compare_acls=1)
+        self.assertTrue(
+            compare_recursive(self.acl_test2_rpath, restore_dir,
+                              compare_acls=1))
 
     def test_acl_mapping(self):
         """Test mapping ACL names"""
@@ -554,7 +533,7 @@ other::---
             rootrp.mkdir()
             rp = rootrp.append('a1')
             rp.touch()
-            acl = AccessControlLists(('a1', ), """user::rwx
+            acl = acl_posix.AccessControlLists(('a1', ), """user::rwx
 user:root:rwx
 user:{0}:---
 user:bin:r--
@@ -566,16 +545,19 @@ other::---""".format(self.current_user, self.current_group))
             rp.write_acl(acl)
             return rp
 
-        def write_mapping_file(rootrp):
-            map_rp = rootrp.append('mapping_file')
-            map_rp.write_string("root:{1}\n{0}:bin\nbin:root".format(
-                self.current_user, self.current_group))
-            return map_rp
+        def write_mapping_files(rootrp):
+            users_map_rp = rootrp.append('users_map_file')
+            users_map_rp.write_string("root:{u}\n{u}:bin\nbin:root".format(
+                u=self.current_user))
+            groups_map_rp = rootrp.append('groups_map_file')
+            groups_map_rp.write_string("root:{g}\n{g}:bin\nbin:root".format(
+                g=self.current_group))
+            return (users_map_rp, groups_map_rp)
 
-        def get_perms_of_user(acl, user):
+        def get_perms(acl, owner, owner_type):
             """Return the permissions of ACL_USER in acl, or None"""
             for typechar, owner_pair, perms in acl.entry_list:
-                if typechar == "u" and owner_pair[1] == user:
+                if typechar == owner_type and owner_pair[1] == owner:
                     return perms
             return None
 
@@ -583,20 +565,22 @@ other::---""".format(self.current_user, self.current_group))
         rootrp = rpath.RPath(Globals.local_connection,
                              os.path.join(abs_test_dir, b'acl_map_test'))
         make_dir(rootrp)
-        map_rp = write_mapping_file(rootrp)
+        (users_map_rp, groups_map_rp) = write_mapping_files(rootrp)
 
-        rdiff_backup(1,
-                     1,
-                     rootrp.path,
-                     tempdir.path,
-                     extra_options=b"--user-mapping-file %b" % (map_rp.path, ))
+        rdiff_backup(
+            1, 1, rootrp.path, tempdir.path,
+            extra_options=b"--user-mapping-file %b --group-mapping-file %b" % (
+                users_map_rp.path, groups_map_rp.path))
 
         out_rp = tempdir.append('a1')
-        assert out_rp.isreg()
+        self.assertTrue(out_rp.isreg())
         out_acl = tempdir.append('a1').get_acl()
-        assert get_perms_of_user(out_acl, 'root') == 4
-        assert get_perms_of_user(out_acl, self.current_user) == 7
-        assert get_perms_of_user(out_acl, 'bin') == 0
+        self.assertEqual(get_perms(out_acl, 'root', 'u'), 4)
+        self.assertEqual(get_perms(out_acl, self.current_user, 'u'), 7)
+        self.assertEqual(get_perms(out_acl, 'bin', 'u'), 0)
+        self.assertEqual(get_perms(out_acl, 'root', 'g'), None)
+        self.assertEqual(get_perms(out_acl, self.current_group, 'g'), 5)
+        self.assertEqual(get_perms(out_acl, 'bin', 'g'), 2)
 
     def test_acl_dropping(self):
         """Test dropping of ACL names"""
@@ -606,7 +590,7 @@ other::---""".format(self.current_user, self.current_group))
         """ben uses a dvorak keyboard, and these sequences are
         analogous to asdfsjkd for a qwerty user... these
         users and groups are not expected to exist. -dean"""
-        acl = AccessControlLists(('a1', ), """user::rwx
+        acl = acl_posix.AccessControlLists(('a1', ), """user::rwx
 user:aoensutheu:r--
 group::r-x
 group:aeuai:r-x
@@ -614,16 +598,12 @@ group:enutohnh:-w-
 other::---""")
         rp.write_acl(acl)
         rp2 = tempdir.append('a1')
-        acl2 = AccessControlLists(('a1', ))
+        acl2 = acl_posix.AccessControlLists(('a1', ))
         acl2.read_from_rp(rp2)
-        assert acl2.is_basic()
+        self.assertTrue(acl2.is_basic())
         Globals.never_drop_acls = 1
-        try:
+        with self.assertRaises(SystemExit):
             rp.write_acl(acl)
-        except SystemExit:
-            pass
-        else:
-            assert 0, "Above should have exited with fatal error"
         Globals.never_drop_acls = None
 
     def test_nochange(self):
@@ -641,8 +621,8 @@ other::---""")
                      tempdir.path,
                      current_time=20000)
         incdir = tempdir.append('rdiff-backup-data', 'increments')
-        assert incdir.isdir(), incdir
-        assert not incdir.listdir(), incdir.listdir()
+        self.assertTrue(incdir.isdir())
+        self.assertFalse(incdir.listdir())
 
 
 class CombinedTest(unittest.TestCase):
