@@ -1,11 +1,15 @@
 import os
-import unittest
 import time
+import unittest
+
 from commontest import (
     abs_test_dir, abs_output_dir, old_test_dir, re_init_rpath_dir,
     compare_recursive, BackupRestoreSeries, InternalBackup, InternalRestore,
     MakeOutputDir, reset_hardlink_dicts, xcopytree
 )
+import commontest as comtst
+import fileset
+
 from rdiff_backup import Globals, Hardlink, rpath, selection
 from rdiffbackup.meta import stdattr
 
@@ -366,5 +370,62 @@ class HardlinkTest(unittest.TestCase):
         self.assertEqual(hlrestore_file2.getinode(), hlrestore_file3.getinode())
 
 
+class BackupUnchangedHardlinksTest(unittest.TestCase):
+    """
+    Test that rdiff-backup doesn't moan about moving hardlinks over same inode
+    """
+
+    def setUp(self):
+        self.base_dir = os.path.join(comtst.abs_test_dir,
+                                     b"hardlink_unchanged")
+        self.from1_struct = {
+            "from1": {"contents": {
+                "fileA": {"content": "initial", "inode": "fileA"},
+                "linkA": {"inode": "fileA"},
+                "fileB": {},  # just as canary
+            }}
+        }
+        self.from1_path = os.path.join(self.base_dir, b"from1")
+        self.from2_struct = {
+            "from2": {"contents": {
+                "fileA": {"content": "initial", "inode": "fileA"},
+                "linkA": {"inode": "fileA"},
+                "fileB": {},  # just as canary
+            }}
+        }
+        self.from2_path = os.path.join(self.base_dir, b"from2")
+        fileset.create_fileset(self.base_dir, self.from1_struct)
+        fileset.create_fileset(self.base_dir, self.from2_struct)
+        fileset.remove_fileset(self.base_dir, {"bak": {"type": "dir"}})
+        fileset.remove_fileset(self.base_dir, {"to1": {"type": "dir"}})
+        fileset.remove_fileset(self.base_dir, {"to2": {"type": "dir"}})
+        self.bak_path = os.path.join(self.base_dir, b"bak")
+        self.to1_path = os.path.join(self.base_dir, b"to1")
+        self.to2_path = os.path.join(self.base_dir, b"to2")
+        self.success = False
+
+    def test_backup_unchanged_hardlinks(self):
+        # we backup twice to the same backup repository at different times
+        self.assertEqual(comtst.rdiff_backup_action(
+            False, False, self.from1_path, self.bak_path,
+            ("--api-version", "201", "--current-time", "10000"),
+            b"backup", ()), 0)
+        self.assertNotIn(
+            b"Attempt to rename over same inode:",
+            comtst.rdiff_backup_action(
+                False, True, self.from2_path, self.bak_path,
+                ("--api-version", "201", "--current-time", "20000"),
+                b"backup", (), return_stderr=True))
+
+    def tearDown(self):
+        # we clean-up only if the test was successful
+        if self.success:
+            fileset.remove_fileset(self.base_dir, self.from1_struct)
+            fileset.remove_fileset(self.base_dir, self.from2_struct)
+            fileset.remove_fileset(self.base_dir, {"bak": {"type": "dir"}})
+            fileset.remove_fileset(self.base_dir, {"to1": {"type": "dir"}})
+            fileset.remove_fileset(self.base_dir, {"to2": {"type": "dir"}})
+
+
 if __name__ == "__main__":
     unittest.main()
