@@ -15,6 +15,11 @@ class RdiffBackupDeleteTest(unittest.TestCase):
 
     repo = ""
 
+    if Globals.get_api_version() < 201:  # compat200
+        ret_code_file_warn = Globals.RET_CODE_OK
+    else:
+        ret_code_file_warn = Globals.RET_CODE_FILE_WARN
+
     # Lookup for rdiff-backup-delete location.
     def _rdiff_backup_delete(self, to_delete=None, extra_args=[],
                              expected_ret_code=0, expected_output=None):
@@ -148,13 +153,15 @@ class RdiffBackupDeleteTest(unittest.TestCase):
     def test_delete_with_fifo(self):
         self._copy_repo(b'restoretest5')
         self._rdiff_backup_delete(to_delete=os.path.join(self.repo, b'fifo'))
-        rdiff_backup(1, 1, self.repo, None, extra_options=b"--verify")
+        rdiff_backup(1, 1, self.repo, None, extra_options=b"--verify",
+                     expected_ret_code=self.ret_code_file_warn)
         self.assertNotFound(b'fifo')
 
     def test_delete_with_non_utf8(self):
         self._copy_repo(b'restoretest5')
         self._rdiff_backup_delete(to_delete=os.path.join(self.repo, b'various_file_types/\xd8\xab\xb1Wb\xae\xc5]\x8a\xbb\x15v*\xf4\x0f!\xf9>\xe2Y\x86\xbb\xab\xdbp\xb0\x84\x13k\x1d\xc2\xf1\xf5e\xa5U\x82\x9aUV\xa0\xf4\xdf4\xba\xfdX\x03\x82\x07s\xce\x9e\x8b\xb34\x04\x9f\x17 \xf4\x8f\xa6\xfa\x97\xab\xd8\xac\xda\x85\xdcKvC\xfa#\x94\x92\x9e\xc9\xb7\xc3_\x0f\x84g\x9aB\x11<=^\xdbM\x13\x96c\x8b\xa7|*"\\\'^$@#!(){}?+ ~` '))
-        rdiff_backup(1, 1, self.repo, None, extra_options=b"--verify")
+        rdiff_backup(1, 1, self.repo, None, extra_options=b"--verify",
+                     expected_ret_code=self.ret_code_file_warn)
 
     def test_delete_access_control_lists(self):
         self._copy_repo(b'restoretest3')
@@ -173,7 +180,8 @@ class RdiffBackupDeleteTest(unittest.TestCase):
         self._copy_repo(b'restoretest4')
         self._rdiff_backup_delete(to_delete=os.path.join(self.repo, b'tmp'),
                                   extra_args=[b'--dry-run'])
-        rdiff_backup(1, 1, self.repo, None, extra_options=b"--verify")
+        rdiff_backup(1, 1, self.repo, None, extra_options=b"--verify",
+                     expected_ret_code=self.ret_code_file_warn)
         self.assertFound(b'tmp')
 
     def test_delete_with_running_backup(self):
